#
# spec file for package python-pymdown-extensions
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pymdown-extensions
Version:        10.7.1
Release:        2.2
Summary:        Extension pack for Python Markdown
License:        MIT
URL:            https://github.com/facelessuser/pymdown-extensions
Source:         https://github.com/facelessuser/pymdown-extensions/archive/refs/tags/%{version}.tar.gz#/pymdown-extensions-%{version}.tar.gz
# PATCH-FIX-OPENSUSE Assert toc_tokens is a superset of what we want to check
Patch0:         fix-toc-list-check.patch
BuildRequires:  %{python_module Markdown >= 3.2}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
# test requirements
BuildRequires:  %{python_module PyYAML >= 3.10}
BuildRequires:  %{python_module Pygments >= 2.12}
BuildRequires:  %{python_module pytest}
#
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Markdown >= 3.2
Requires:       python-PyYAML >= 3.10
Recommends:     python-Pygments >= 2.12
BuildArch:      noarch
%python_subpackages

%description
PyMdown Extensions is a collection of extensions for Python Markdown.

They were originally written to make writing documentation more enjoyable.
Covering a wide range of solutions, and while not every extension is needed
by all people, there is usually at least one useful extension for anybody.

%prep
%autosetup -p1 -n pymdown-extensions-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
find %{buildroot} -type f -name "*.py" -exec chmod a-x {} +
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/pymdownx
%{python_sitelib}/pymdown_extensions-%{version}.dist-info

%changelog
* Fri Mar 22 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch fix-toc-list-check.patch:
  * Assert toc_tokens is a superset of what we are looking for.
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 10.7.1:
  * SmartSymbols: Ensure symbols are properly translated in table
    of content tokens.
* Sun Dec 31 2023 Dirk Müller <dmueller@suse.com>
- update to 10.7:
  * NEW: Emoji: Update Twemoji and Gemoji data to latest.
  * NEW: Emoji: Due to recent Gemoji update, non-standard emoji
    are no longer indexed. So emoji such as :octocat: are no
    longer resolved.
  * NEW: Highlight: Added new option default_lang which will
    cause code blocks with no language specifier to be
    highlighted with the specified default language instead of
    plain text. This affects indented code blocks and code blocks
    defined with SuperFences.
  * NEW: InlineHilite: style_plain_text can be specified with a
    language string (in addition to its previous boolean
    requirement) to treat inline code blocks with no explicit
    language specifier with a specific default language.
  * NEW: MagicLink: Allow configuring custom
    repository providers based off the existing providers.
* Thu Dec 14 2023 Elisei Roca <eroca@mailbox.org>
- update to 10.5:
  * NEW: Blocks: Admonitions and Details now allow configuring
    custom block classes and default titles.
  * FIX: Keys: Ensure that Keys does not parse base64 encoded URLs.
- from 10.4:
  * NEW: Snippets: Allow PathLike objects for base_path to better
    support interactions with MkDocs.
  * FIX: Block Admonitions: Empty titles should be respected.
  * FIX: Block Details: Empty summary should be respected.
- from 10.3.1:
  * FIX: SuperFences: Fix an issue where braces were not handled
    properly in attributes.
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 10.3:
  * NEW: Officially support Python 3.12.
  * NEW: Drop Python 3.7 support.
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 10.2.1 (skipping non-existent 10.2.0 release):
  * FIX: Tabbed: Fix regression.
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 10.1.0:
  * NEW: Add new combine_header_slug option in legacy Tabbed
    extension and new Block Tab extension that will
    prefix a content tab's slug with the parent header's slug. This
    allows for content tab slugs that are scoped to the
    header they are under.
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 10.0.1:
  * FIX: Regression related to snippets nested deeply under
    specified base path.
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 10.0:
  * Break: Snippets: snippets will restrict snippets to ensure they
    are under the base_path preventing snippets relative to the
    base_path but not explicitly under it. restrict_base_path can
    be set to False for legacy behavior.
* Mon Apr 24 2023 Elisei Roca <eroca@mailbox.org>
- require python-PyYAML from requirements/project.txt
- recommend python-Pygments from requirements/extra.txt
- update to 9.11:
  * NEW: Emoji: Update to new CDN and use Twemoji 14.1.2.
  * NEW: Snippets: Ignore nested snippet section syntax when including a section.
* Fri Mar 17 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.10:
  * NEW: Blocks: Add new experimental general purpose blocks that
    provide a framework for creating fenced block containers for
    specialized parsing. A number of extensions utilizing general
    purpose blocks are included and are meant to be an alternative
    to (and maybe one day replace): Admonitions, Details,
    Definition Lists, and Tabbed. Also adds a new HTML plugin for
    quick wrapping of content with arbitrary HTML elements.
  * NEW: Highlight: When enabling line spans and/or line anchors,
    if a code block has an ID associated with it, line ids will be
    generated using that code ID instead of the code block count.
  * NEW: Snippets: Expand section syntax to allow section names
    with `-` and `_`.
  * NEW: Snippets: When check_paths is enabled, and a specified
    section is not found, raise an error.
  * NEW: Snippets: Add new experimental feature dedent_sections
    that will de-indent (remove any common leading
    whitespace from every line in text) from that block of text.
  * NEW: MagicLink: Update GitLab links to match recent changes and
    to be more correct.
  * NEW: MagicLink: Relax required hash length when performing link
    shortening.
- update to 9.9.2:
  * FIX: Snippets syntax can break in XML comments as XML comments
    do not allow --. Relax Snippets syntax such that
  - 8<- (single -) are allowed.
* Thu Jan 19 2023 Elisei Roca <eroca@mailbox.org>
- Initial commit of pymdown-extensions at version 9.9.1
